@@ -6,9 +6,10 @@
  * Provides the client half of the process.  Should be considered
  * untrusted by the privman server.
  *
- * $Id: priv_client.cc,v 1.19 2002/08/27 23:16:09 dougk Exp $
+ * $Id: priv_client.cc,v 1.22 2002/09/17 20:28:33 dougk Exp $
  */
 
+#include "../config.h"
 #include <stdarg.h>
 #include <stdlib.h>
 #include <strings.h>
@@ -57,9 +58,9 @@ static void readConfig(const char *progname) {
     yyin = fopen(pathname, "r");
  
     if (yyin == NULL) {
-        fprintf(stderr,"Error: missing privmand configuration file\n");
+        syslog(LOG_ERR,"Error: missing privmand configuration file\n");
     } else if (yyparse() != 0) {
-        fprintf(stderr,"Error reading privmand configuration file\n");
+        syslog(LOG_ERR,"Error reading privmand configuration file\n");
     } 
     if (yyin != NULL)
         fclose(yyin);
@@ -122,7 +123,7 @@ void wait_for_debugger(void)
      * place to attach the debugger.
      */
     volatile int i = 0;
-    fprintf(stderr,"waiting for debugger\n");
+    syslog(LOG_ALERT,"waiting for debugger\n");
     while (i == 0)
         sleep(1);
 #endif
@@ -165,18 +166,22 @@ void setup_child(int sockfds[2],
      * to clear it, so just leak it.
      */
 
-    if (pwent == NULL) 
-        boom("getpwnam");
+    if (pwent == NULL) {
+        syslog(LOG_ERR, "getpwnam failed on unpriv user %s",
+            config->unpriv_user.c_str());
+        boom("setup_child(getpwnam)");
+    }
 
     /* chroot */
     if (chroot(config->unpriv_jail.c_str()) < 0) {
-        fprintf(stderr, "chroot to %s\n", config->unpriv_jail.c_str());
+        syslog(LOG_ERR, "chroot to %s\n", config->unpriv_jail.c_str());
         boom("setup_child(chroot)");
     }
 
-    /* setuid, drop priviledge. */
-    setreuid(pwent->pw_uid,pwent->pw_uid);
-    setregid(pwent->pw_gid,pwent->pw_gid);
+    if (setgid(pwent->pw_gid) < 0)
+        boom("setup_child(setgid)");
+    if (setuid(pwent->pw_uid) < 0)
+        boom("setup_child(setuid)");
 
     /* Call provilded function */
     if (fnptr != NULL) {
