@@ -6,8 +6,9 @@
  * Provides the server half of the process.  This half retains priviledge
  * and should be nei-invulnerable.
  *
- * $Id: privman.cc,v 1.32 2002/08/30 20:05:07 dougk Exp $
+ * $Id: privman.cc,v 1.34 2002/09/16 20:06:14 dougk Exp $
  */
+#include "../config.h"
 #include <stdio.h>
 #include <errno.h>
 #include <stdlib.h>
@@ -24,11 +25,6 @@
 #include <sys/wait.h>
 #include <syslog.h>
 
-extern "C" {
-    /* sockaddr_in */
-#include <security/pam_appl.h>
-}
-
 #include <map>
 
 #include "privman.h"
@@ -266,7 +262,7 @@ static void openFile(message_t *msg) {
         rfd = open(canpath,flags,mode);
         if (rfd < 0) {
             msg_initResponce(msg, -errno);
-            perror("msg_open_file(open)");
+            syslog(LOG_WARNING, "msg_open_file(open): %m");
         } else {
             msg_initResponce(msg, 0);
             msg_setFd(msg,rfd);
@@ -682,6 +678,7 @@ static bool validRequest(enum commands c) {
     case CMD_PAM_GETENV:
     case CMD_PAM_PUTENV:
     case CMD_PAM_CHAUTHTOK:
+    case CMD_PAM_FAIL_DELAY:
         return config->auth;
     case CMD_SETUID:
         return false;
@@ -717,7 +714,7 @@ static void control_loop(void) {
         /* The handler function for a given request does the responce. */
         void (*fnptr)(message_t*) = function_map[c];
         if (fnptr == NULL) {
-            fprintf(stderr, "libprivman: bad command (c = %c)\n", c);
+            syslog(LOG_ERR, "libprivman: bad command (c = %c)", c);
             boom("control_loop(unknown command)");
         }
         /* Call the handler */
